import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import { Head, Link, router } from "@inertiajs/react";
import { usePage } from "@inertiajs/react";
import { columns } from "./Columns";
import { PaginatedData, User } from "@/types";
import { DataTable } from "@/Components/DataTable";
import { Input } from "@/Components/ui/input";
import { useCallback, useState } from "react";
import { ChangeEvent } from "react";
import { CreateButton } from "@/Components/ui/create-button";

import { useSearchParam } from "react-use";
import { PageProps } from "@/types";

interface LocalPageProps extends PageProps {
    users: PaginatedData<User>;
}

export default function Index() {
    const { users } = usePage<LocalPageProps>().props;

    const params = useSearchParam("search");

    const [originParam, setOriginParam] = useState(params ?? "");

    const searchUsers = useCallback(
        (e: ChangeEvent<HTMLInputElement>) => {
            setOriginParam(e.target.value);
            const currentRoute = route().current();

            if (currentRoute) {
                router.get(
                    currentRoute,
                    { search: e.target.value },
                    {
                        replace: true,
                        preserveState: true,
                    }
                );
            } else {
                // Handle the case where the current route is undefined (fallback to a default route or show an error)
                console.error("Current route is undefined");
            }
        },
        [originParam]
    );

    return (
        <AuthenticatedLayout>
            <Head title="User" />

            <div className="bg-white shadow-md rounded px-8 pt-6 pb-8 m-5">
                <div className={"flex justify-between  p-3"}>
                    <div className={"pb-5 text-2xl font-bold"}>
                        <strong>Users</strong>
                    </div>
                    <div>
                        <div className={"flex mx-4 gap-2"}>
                            <Input
                                placeholder={"Search"}
                                onChange={searchUsers}
                                value={originParam}
                            ></Input>
                            <CreateButton>
                                <Link
                                    href={"/users/create"}
                                >
                                    Create
                                </Link>
                            </CreateButton>
                        </div>
                    </div>
                </div>
                <DataTable columns={columns} data={users.data} />
            </div>
        </AuthenticatedLayout>
    );
}
